==> apache-apisix-dashboard-2.13.1-src.tgz: web/src/locales/tr-TR/component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  'component.tagSelect.expand': 'Genişlet',
  'component.tagSelect.collapse': 'Daralt',
  'component.tagSelect.all': 'Tümü',
  'component.global.search': 'Ara',
  'component.global.reset': 'Sıfırla',
  'component.global.confirm': 'Onayla',
  'component.global.format': 'Biçimlendir',
  'component.global.document': 'Doküman',
  'component.global.enable': 'Aktifleştir',
  'component.global.disable': 'Devre dışı bırak',
  'component.global.scope': 'Kapsam',
  'component.global.data.editor': 'Veri Editörü',
  'component.global.delete': 'Sil',
  'component.global.cancel': 'İptal',
  'component.global.submit': 'Gönder',
  'component.global.create': 'Oluştur',
  'component.global.add': 'Ekle',
  'component.global.save': 'Kaydet',
  'component.global.edit': 'Düzenle',
  'component.global.view': 'Görüntüle',
  'component.global.duplicate': 'Çoğalt',
  'component.global.manage': 'Yönet',
  'component.global.update': 'Güncelle',
  'component.global.get': 'Al',
  'component.global.edit.plugin': 'Eklenti Düzenle',
  'component.global.loading': 'Yükleniyor',
  'component.global.list': 'Liste',
  'component.global.description': 'Açıklama',
  'component.global.description.required': 'Açıklama gerekli',
  'component.global.labels': 'Etiketler',
  'component.global.version': 'Sürüm',
  'component.global.operation': 'İşlem',
  'component.status.success': 'Başarılı',
  'component.status.fail': 'Başarısız',
  'component.global.popconfirm.title.delete': 'Silmek istediğinizden emin misiniz?',
  'component.global.notification.success.message.deleteSuccess': 'Başarıyla silindi',
  'component.global.create.consumer.success': 'Başarıyla oluşturuldu',
  'component.global.delete.consumer.success': 'Başarıyla silindi',
  'component.global.edit.consumer.success': 'Başarıyla güncellendi',

  'component.global.steps.stepTitle.basicInformation': 'Temel Bilgiler',
  'component.global.steps.stepTitle.preview': 'Önizleme',
  'component.global.steps.stepTitle.pluginConfig': 'Eklenti Ayarları',

  'component.global.pleaseEnter': 'Lütfen girin',
  'component.global.pleaseChoose': 'Lütfen seçin',
  'component.global.pleaseCheck': 'Lütfen kontrol edin',

  'component.global.input.ruleMessage.name':
    'Sadece harfler sayılar ve -,_ kullanılabilir. Ayrıca harf ile başlamalıdır.',

  'component.global.connectionTimeout': 'Bağlantı zaman aşımı',
  'component.global.sendTimeout': 'Zaman aşımı gönder',
  'component.global.receiveTimeout': 'Zaman aşımı al',
  'component.global.name': 'Ad',
  'component.global.id': 'ID',
  'component.global.updateTime': 'Zamanı Güncelle',
  'component.global.form.itemExtraMessage.nameGloballyUnique': 'İsim global olarak benzersiz olmalıdır',
  'component.global.input.placeholder.description':
    'Açıklama girin, max 256 karakter',
  // User component
  'component.user.loginByPassword': 'Kullanıcı adı ve şifre',
  'component.user.login': 'Giriş',

  'component.document': 'Doküman',
  'component.label-manager': 'Etiket Yöneticisi',

  'component.global.noConfigurationRequired': 'Yapılandırma gerekli değil',
  'component.global.copy': 'Kopyala',
  'component.global.copySuccess': 'Başarıyla kopyalandı',
  'component.global.copyFail': 'Kopyalama başarısız',

  'component.global.invalidYaml': 'Geçersiz YAML',
  'component.global.invalidJson': 'Geçersiz JSON',
};

==> apache-apisix-dashboard-2.14.0-src.tgz: web/src/locales/tr-TR/component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  'component.tagSelect.expand': 'Genişlet',
  'component.tagSelect.collapse': 'Daralt',
  'component.tagSelect.all': 'Tümü',
  'component.global.search': 'Ara',
  'component.global.reset': 'Sıfırla',
  'component.global.confirm': 'Onayla',
  'component.global.format': 'Biçimlendir',
  'component.global.document': 'Doküman',
  'component.global.enable': 'Aktifleştir',
  'component.global.disable': 'Devre dışı bırak',
  'component.global.scope': 'Kapsam',
  'component.global.example': 'Örnek',
  'component.global.data.editor': 'Veri Editörü',
  'component.global.delete': 'Sil',
  'component.global.cancel': 'İptal',
  'component.global.submit': 'Gönder',
  'component.global.create': 'Oluştur',
  'component.global.add': 'Ekle',
  'component.global.save': 'Kaydet',
  'component.global.edit': 'Düzenle',
  'component.global.view': 'Görüntüle',
  'component.global.duplicate': 'Çoğalt',
  'component.global.manage': 'Yönet',
  'component.global.update': 'Güncelle',
  'component.global.get': 'Al',
  'component.global.edit.plugin': 'Eklenti Düzenle',
  'component.global.loading': 'Yükleniyor',
  'component.global.list': 'Liste',
  'component.global.description': 'Açıklama',
  'component.global.description.required': 'Açıklama gerekli',
  'component.global.labels': 'Etiketler',
  'component.global.version': 'Sürüm',
  'component.global.operation': 'İşlem',
  'component.status.success': 'Başarılı',
  'component.status.fail': 'Başarısız',
  'component.global.popconfirm.title.delete': 'Silmek istediğinizden emin misiniz?',
  'component.global.notification.success.message.deleteSuccess': 'Başarıyla silindi',
  'component.global.create.consumer.success': 'Başarıyla oluşturuldu',
  'component.global.delete.consumer.success': 'Başarıyla silindi',
  'component.global.delete.routes.success': 'Sil Yöneltmeler Başarılı',
  'component.global.edit.consumer.success': 'Başarıyla güncellendi',

  'component.global.steps.stepTitle.basicInformation': 'Temel Bilgiler',
  'component.global.steps.stepTitle.preview': 'Önizleme',
  'component.global.steps.stepTitle.pluginConfig': 'Eklenti Ayarları',

  'component.global.pleaseEnter': 'Lütfen girin',
  'component.global.pleaseChoose': 'Lütfen seçin',
  'component.global.pleaseCheck': 'Lütfen kontrol edin',

  'component.global.input.ruleMessage.name':
    'Sadece harfler sayılar ve -,_ kullanılabilir. Ayrıca harf ile başlamalıdır.',

  'component.global.connectionTimeout': 'Bağlantı zaman aşımı',
  'component.global.sendTimeout': 'Zaman aşımı gönder',
  'component.global.receiveTimeout': 'Zaman aşımı al',
  'component.global.name': 'Ad',
  'component.global.id': 'ID',
  'component.global.updateTime': 'Zamanı Güncelle',
  'component.global.form.itemExtraMessage.nameGloballyUnique':
    'İsim global olarak benzersiz olmalıdır',
  'component.global.input.placeholder.description': 'Açıklama girin, max 256 karakter',
  // User component
  'component.user.loginByPassword': 'Kullanıcı adı ve şifre',
  'component.user.login': 'Giriş',

  'component.document': 'Doküman',
  'component.label-manager': 'Etiket Yöneticisi',

  'component.global.noConfigurationRequired': 'Yapılandırma gerekli değil',
  'component.global.copy': 'Kopyala',
  'component.global.copySuccess': 'Başarıyla kopyalandı',
  'component.global.copyFail': 'Kopyalama başarısız',

  'component.global.invalidYaml': 'Geçersiz YAML',
  'component.global.invalidJson': 'Geçersiz JSON',
};
